const URL = 'https://api.mainnet-beta.solana.com/';

export function useBlock(blockId) {
    const [res, setRes] = React.useState({});
    const [isLoading, setIsLoading] = React.useState(true);

    React.useEffect(() => {
        (async function() {
            const blockIdToNumber = Number(blockId);
            if(Number.isNaN(blockIdToNumber)) throw new Error('Block ID is not number!');

            const body = {
                id: "f15384d0-3c1f-4518-a1c4-dcbb9a070ec8",
                jsonrpc: "2.0",
                method: "getConfirmedBlock",
                params: [blockIdToNumber]
            }
            const req = await fetch(URL, {
                method: 'POST',
                cache: 'no-cache',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify(body),
            });
            setRes((await req.json()).result);
            setIsLoading(false);
        })()
    }, [blockId]);

    return [res, isLoading]
}

export function useAccount(accountId) {
    const [res, setRes] = React.useState({});
    const [isLoading, setIsLoading] = React.useState(true);

    React.useEffect(() => {
        (async function() {
            const body = {
                id: "2a693945-785f-4cfb-b5ad-c122730b3abb",
                jsonrpc: "2.0",
                method: "getAccountInfo",
                params: [accountId, {encoding: "base64"}]
            }
            const req = await fetch(URL, {
                method: 'POST',
                cache: 'no-cache',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify(body),
            });
            setRes((await req.json()).result);
            setIsLoading(false);
        })()
    }, [accountId]);

    return [res, isLoading]
}

export function useTransaction(txId, parse = true) {
    const [res, setRes] = React.useState({});
    const [isLoading, setIsLoading] = React.useState(true);

    React.useEffect(() => {
        (async function() {
            const body = {
                id: "eacdf4bb-a812-4f87-a7b5-921d10dbc558",
                jsonrpc: "2.0",
                method: "getConfirmedTransaction",
                params: parse?[txId, 'jsonParsed']:[txId]
            }
            const req = await fetch(URL, {
                method: 'POST',
                cache: 'no-cache',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify(body),
            });
            setRes((await req.json()).result);
            setIsLoading(false);
        })()
    }, [txId]);

    return [res, isLoading]
}